Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(278)

Unified Diff: webrtc/api/objc/RTCVideoRendererAdapter+Private.h

Issue 1817473002: Delete VideoRendererInterface. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Rebase. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/api/objc/RTCVideoRendererAdapter.mm ('k') | webrtc/api/objc/RTCVideoTrack.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/api/objc/RTCVideoRendererAdapter+Private.h
diff --git a/webrtc/api/objc/RTCVideoRendererAdapter+Private.h b/webrtc/api/objc/RTCVideoRendererAdapter+Private.h
index c181b9b41c8fb1511e0059d29be808e2ec70e12e..f0e0c6c0adda956fdae989054ffd58891b959a8d 100644
--- a/webrtc/api/objc/RTCVideoRendererAdapter+Private.h
+++ b/webrtc/api/objc/RTCVideoRendererAdapter+Private.h
@@ -26,12 +26,12 @@ NS_ASSUME_NONNULL_BEGIN
@property(nonatomic, readonly) id<RTCVideoRenderer> videoRenderer;
/**
* The native VideoRendererInterface surface exposed by this adapter. Calls made
* to this interface will be adapted and passed to the RTCVideoRenderer supplied
* during construction. This pointer is unsafe and owned by this class.
*/
@property(nonatomic, readonly)
- webrtc::VideoRendererInterface *nativeVideoRenderer;
+ rtc::VideoSinkInterface<cricket::VideoFrame> *nativeVideoRenderer;
/** Initialize an RTCVideoRendererAdapter with an RTCVideoRenderer. */
- (instancetype)initWithNativeRenderer:(id<RTCVideoRenderer>)videoRenderer
« no previous file with comments | « webrtc/api/objc/RTCVideoRendererAdapter.mm ('k') | webrtc/api/objc/RTCVideoTrack.mm » ('j') | no next file with comments »

Powered by Google App Engine
@@ -26,12 +26,12 @@ NS_ASSUME_NONNULL_BEGIN
/**
- * The native VideoRendererInterface surface exposed by this adapter. Calls made
+ * The native VideoSinkInterface surface exposed by this adapter. Calls made
* to this interface will be adapted and passed to the RTCVideoRenderer supplied
* during construction. This pointer is unsafe and owned by this class.
This is Rietveld 408576698